@@ -56,10 +56,10 @@
 #include <FileTools/FileManip.h>
 #include <FileTools/PathManip.h>
 #include <SystemTools/UserDatabase.h>
-#include <Utils/SystemTime.h>
+#include <SystemTools/SystemTime.h>
 #include <Utils/Timer.h>
-#include <Utils/IOUtils.h>
-#include <Utils/StrIntUtils.h>
+#include <IOTools/IOUtils.h>
+#include <StrIntTools/StrIntUtils.h>
 #include <Core/SpawningKit/Context.h>
 #include <Core/SpawningKit/Config.h>
 #include <Core/SpawningKit/Journey.h>
@@ -123,7 +123,7 @@ private:
 
 	void createWorkDir() {
 		TRACE_POINT();
-		session.workDir.reset(new HandshakeWorkDir());
+		session.workDir.reset(new HandshakeWorkDir(context->spawnDir));
 
 		session.envDumpDir = session.workDir->getPath() + "/envdump";
 		makeDirTree(session.envDumpDir,
@@ -249,6 +249,10 @@ private:
 		args["integration_mode"] = context->integrationMode;
 		args["gupid"] = session.result.gupid;
 		args["UNIX_PATH_MAX"] = (Json::UInt64) sizeof(addr.sun_path) - 1;
+
+		if (config->preloadBundler) {
+			args["preload_bundler"] = config->preloadBundler;
+		}
 		if (config->genericApp || config->findFreePort) {
 			args["expected_start_port"] = session.expectedStartPort;
 		}
